# Upbit Open API
#
# ## REST API for Upbit Exchange - Base URL: [https://api.upbit.com] - Official Upbit API Documents: [https://docs.upbit.com] - Official Support email: [open-api@upbit.com] 
#
# OpenAPI spec version: 1.0.0
# Contact: ujhin942@gmail.com
# Generated by: https://github.com/swagger-api/swagger-codegen.git

#' @title Order operations
#' @description swagger.Order
#'
#' @field path Stores url path of the request.
#' @field apiClient Handles the client-server communication.
#' @field userAgent Set the user agent of the request.
#'
#' @importFrom R6 R6Class
#'
#' @section Methods:
#' \describe{
#'
#' order_cancel 주문 취소 접수
#'
#'
#' order_chance 주문 가능 정보
#'
#'
#' order_info 개별 주문 조회
#'
#'
#' order_info_all 주문 리스트 조회
#'
#'
#' order_new 주문하기
#'
#'
#' order_orderbook 시세 호가 정보(Orderbook) 조회
#'
#' }
#'
#' @export
OrderApi <- R6::R6Class(
  'OrderApi',
  public = list(
    userAgent = "Swagger-Codegen/1.0.0/r",
    apiClient = NULL,
    initialize = function(apiClient){
      if (!missing(apiClient)) {
        self$apiClient <- apiClient
      }
      else {
        self$apiClient <- ApiClient$new()
      }
    },
    order_cancel = function(uuid, identifier, ...){
      args <- list(...)
      queryParams <- list()
      headerParams <- character()

      if (!missing(`uuid`)) {
        queryParams['uuid'] <- uuid
      }

      if (!missing(`identifier`)) {
        queryParams['identifier'] <- identifier
      }

      urlPath <- "/order"
      resp <- self$apiClient$callApi(url = paste0(self$apiClient$basePath, urlPath),
                                 method = "DELETE",
                                 queryParams = queryParams,
                                 headerParams = headerParams,
                                 body = body,
                                 ...)
      
      if (httr::status_code(resp) >= 200 && httr::status_code(resp) <= 299) {
        returnObject <- Order$new()
        result <- returnObject$fromJSON(httr::content(resp, "text", encoding = "UTF-8"))
        Response$new(returnObject, resp)
      } else if (httr::status_code(resp) >= 400 && httr::status_code(resp) <= 499) {
        Response$new("API client error", resp)
      } else if (httr::status_code(resp) >= 500 && httr::status_code(resp) <= 599) {
        Response$new("API server error", resp)
      }

    },
    order_chance = function(market, ...){
      args <- list(...)
      queryParams <- list()
      headerParams <- character()

      if (!missing(`market`)) {
        queryParams['market'] <- market
      }

      urlPath <- "/orders/chance"
      resp <- self$apiClient$callApi(url = paste0(self$apiClient$basePath, urlPath),
                                 method = "GET",
                                 queryParams = queryParams,
                                 headerParams = headerParams,
                                 body = body,
                                 ...)
      
      if (httr::status_code(resp) >= 200 && httr::status_code(resp) <= 299) {
        returnObject <- OrderChance$new()
        result <- returnObject$fromJSON(httr::content(resp, "text", encoding = "UTF-8"))
        Response$new(returnObject, resp)
      } else if (httr::status_code(resp) >= 400 && httr::status_code(resp) <= 499) {
        Response$new("API client error", resp)
      } else if (httr::status_code(resp) >= 500 && httr::status_code(resp) <= 599) {
        Response$new("API server error", resp)
      }

    },
    order_info = function(uuid, identifier, ...){
      args <- list(...)
      queryParams <- list()
      headerParams <- character()

      if (!missing(`uuid`)) {
        queryParams['uuid'] <- uuid
      }

      if (!missing(`identifier`)) {
        queryParams['identifier'] <- identifier
      }

      urlPath <- "/order"
      resp <- self$apiClient$callApi(url = paste0(self$apiClient$basePath, urlPath),
                                 method = "GET",
                                 queryParams = queryParams,
                                 headerParams = headerParams,
                                 body = body,
                                 ...)
      
      if (httr::status_code(resp) >= 200 && httr::status_code(resp) <= 299) {
        returnObject <- OrderInfo$new()
        result <- returnObject$fromJSON(httr::content(resp, "text", encoding = "UTF-8"))
        Response$new(returnObject, resp)
      } else if (httr::status_code(resp) >= 400 && httr::status_code(resp) <= 499) {
        Response$new("API client error", resp)
      } else if (httr::status_code(resp) >= 500 && httr::status_code(resp) <= 599) {
        Response$new("API server error", resp)
      }

    },
    order_info_all = function(market, state, states, uuids, identifiers, page, limit, order_by, ...){
      args <- list(...)
      queryParams <- list()
      headerParams <- character()

      if (!missing(`market`)) {
        queryParams['market'] <- market
      }

      if (!missing(`state`)) {
        queryParams['state'] <- state
      }

      if (!missing(`states`)) {
        queryParams['states'] <- states
      }

      if (!missing(`uuids`)) {
        queryParams['uuids'] <- uuids
      }

      if (!missing(`identifiers`)) {
        queryParams['identifiers'] <- identifiers
      }

      if (!missing(`page`)) {
        queryParams['page'] <- page
      }

      if (!missing(`limit`)) {
        queryParams['limit'] <- limit
      }

      if (!missing(`order_by`)) {
        queryParams['order_by'] <- order_by
      }

      urlPath <- "/orders"
      resp <- self$apiClient$callApi(url = paste0(self$apiClient$basePath, urlPath),
                                 method = "GET",
                                 queryParams = queryParams,
                                 headerParams = headerParams,
                                 body = body,
                                 ...)
      
      if (httr::status_code(resp) >= 200 && httr::status_code(resp) <= 299) {
        returnObject <- Order$new()
        result <- returnObject$fromJSON(httr::content(resp, "text", encoding = "UTF-8"))
        Response$new(returnObject, resp)
      } else if (httr::status_code(resp) >= 400 && httr::status_code(resp) <= 499) {
        Response$new("API client error", resp)
      } else if (httr::status_code(resp) >= 500 && httr::status_code(resp) <= 599) {
        Response$new("API server error", resp)
      }

    },
    order_new = function(market, side, ord_type, volume, price, identifier, ...){
      args <- list(...)
      queryParams <- list()
      headerParams <- character()

      body <- list(
          "market" = market,
          "side" = side,
          "volume" = volume,
          "price" = price,
          "ord_type" = ord_type,
          "identifier" = identifier
      )

      urlPath <- "/orders"
      resp <- self$apiClient$callApi(url = paste0(self$apiClient$basePath, urlPath),
                                 method = "POST",
                                 queryParams = queryParams,
                                 headerParams = headerParams,
                                 body = body,
                                 ...)
      
      if (httr::status_code(resp) >= 200 && httr::status_code(resp) <= 299) {
        returnObject <- NewOrder$new()
        result <- returnObject$fromJSON(httr::content(resp, "text", encoding = "UTF-8"))
        Response$new(returnObject, resp)
      } else if (httr::status_code(resp) >= 400 && httr::status_code(resp) <= 499) {
        Response$new("API client error", resp)
      } else if (httr::status_code(resp) >= 500 && httr::status_code(resp) <= 599) {
        Response$new("API server error", resp)
      }

    },
    order_orderbook = function(markets, ...){
      args <- list(...)
      queryParams <- list()
      headerParams <- character()

      if (!missing(`markets`)) {
        queryParams['markets'] <- markets
      }

      urlPath <- "/orderbook"
      resp <- self$apiClient$callApi(url = paste0(self$apiClient$basePath, urlPath),
                                 method = "GET",
                                 queryParams = queryParams,
                                 headerParams = headerParams,
                                 body = body,
                                 ...)
      
      if (httr::status_code(resp) >= 200 && httr::status_code(resp) <= 299) {
        returnObject <- Orderbook$new()
        result <- returnObject$fromJSON(httr::content(resp, "text", encoding = "UTF-8"))
        Response$new(returnObject, resp)
      } else if (httr::status_code(resp) >= 400 && httr::status_code(resp) <= 499) {
        Response$new("API client error", resp)
      } else if (httr::status_code(resp) >= 500 && httr::status_code(resp) <= 599) {
        Response$new("API server error", resp)
      }

    }
  )
)
